#
# spec file for package mate-user-share
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _version 1.28

Name:           mate-user-share
Version:        1.28.0
Release:        1.3
Summary:        MATE Desktop file sharing for the masses
License:        GPL-2.0-or-later
Group:          Productivity/Networking/File-Sharing
URL:            https://mate-desktop.org/
Source:         https://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  gnome-doc-utils
BuildRequires:  hicolor-icon-theme
BuildRequires:  mate-common >= %{_version}
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libcaja-extension) >= %{_version}
BuildRequires:  pkgconfig(libcanberra-gtk3)
BuildRequires:  pkgconfig(libnotify)
Recommends:     %{name}-lang
%glib2_gsettings_schema_requires

%description
mate-user-share is a small package that binds together various
free software projects to bring easy to use user-level file sharing
to the masses.

%package doc
Group:          Documentation/HTML
Summary:        Documentation how to Use mate-user-share
BuildArch:      noarch

%description doc
This package contains the documentation for mate-user-share

%lang_package

%prep
%autosetup

%build
NOCONFIGURE=1 mate-autogen
%configure \
  --libexecdir=%{_libexecdir}/%{name}
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name} %{?no_lang_C}
%suse_update_desktop_file %{name}-properties
%fdupes -s %{buildroot}/%{_datadir}/help

%files
%license COPYING
%doc NEWS README
%config %{_sysconfdir}/xdg/autostart/mate-user-share-*.desktop
%{_bindir}/mate-file-share-properties
%{_mandir}/man?/mate-file-share-properties.?%{?ext_man}
%{_libexecdir}/%{name}/
%{_libdir}/caja/extensions-2.0/libcaja-user-share.so
%{_datadir}/%{name}/
%{_datadir}/caja/extensions/libcaja-user-share.caja-extension
%{_datadir}/applications/mate-user-share-properties.desktop
%{_datadir}/icons/hicolor/*/apps/mate-obex-server.png
%{_datadir}/glib-2.0/schemas/org.mate.FileSharing.gschema.xml

%files doc
%doc %{_datadir}/help/*/%{name}/

%files lang -f %{name}.lang
%exclude %{_datadir}/help/*

%changelog
* Sun Mar 31 2024 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.28.0
  * Translations update
  * fix warnings in Galician and Lithuanian translations
* Sun Aug 22 2021 Jan Engelhardt <jengelh@inai.de>
- Make doc package noarch.
* Fri Aug 13 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.26.0
  * update translations
  * pre-bump version
  * build: allow users to disable gettext support (--disable-nls)
  * Update copyright to 2021
  * Remove the execution bit from some Italian figures
  * Remove USE_MATE2_MACROS from autogen.sh (legacy)
  * Update README
* Wed Feb 26 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.0:
  * Avoid redundant redeclarations.
  * desktop files: Add translator hints.
  * Let xgettext recognise caja-extension.in as a desktop file.
  * Let Description in .caja-extension be translatable.
  * Migrate from intltool to gettext.
  * Update translations.
- Drop support for old openSUSE versions.
* Thu Jul 18 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 1.23.0:
  * Translations update
  * silent output
  * Fix HTTPD config notice
  * help: update copyright
- remove patch:
  * mate-user-share-gtk-3.20.patch: we don't support gtk3.22
    anymore
- build require gtk >= 3.22 and glib >= 2.50
- reduce duplicated files with fdupes
* Tue Mar  5 2019 sor.alexei@meowr.ru
- Update to version 1.22.0:
  * caja-share-bar: Avoid deprecated g_type_class_add_private.
  * Drop obsolete configure option from distcheck.
  * Use make functions for HELP_LINGUAS.
  * Disable deprecation warnings for distcheck.
  * file-share-properties.ui: Avoid deprecations.
  * Use the same legal.xml file.
  * Update translations.
- Rebase mate-user-share-gtk-3.20.patch.
* Fri Jun 22 2018 sor.alexei@meowr.ru
- Update to version 1.20.1:
  * Update translations.
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 1.20.0:
  * Require GTK+ 3.22 and GLib 2.50.
  * build: Use correct macros to fix cross-build.
  * don't use deprecated gtk_show_uri().
  * Update translations.
- Add mate-user-share-gtk-3.20.patch: Restore GLib 2.48 and
  GTK+ 3.20 support.
* Tue Mar 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.0:
  * Move to GTK+3 (>= 3.14), drop the GTK+2 code and --with-gtk
    build option.
  * Update translations.
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 1.16.0:
  * Build: Use 'm4' dir for m4 macros, like in other projects.
  * GTK+3: Port from libunique to GtkApplication.
  * Make distcheck use a currently selected GTK+ version.
  * Update translations.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 1.14.0:
  * Drop MateConf migration script.
  * Update translations.
  * Fix Changelog generation
* Wed Jan 27 2016 sor.alexei@meowr.ru
- Update to version 1.13.0:
  * Don't translate Keywords field in .desktop files.
  * Drop MateConf migration script.
  * GTK+3: Fix some deprecations.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 1.12.0.
* Wed Oct 14 2015 sor.alexei@meowr.ru
- Update to 1.11.0:
  * Switch to org.gnome.SessionManager (used for BT services
    start/stop).
  * Drop useless dependency on dbus-1.
  * Drop Apache 2.0 support.
  * Some more cleanups.
* Wed May  6 2015 sor.alexei@meowr.ru
- Update to 1.10.0 (changes since 1.9.0):
  * Add missing variable type in user_share.c.
  * Fix logic flow (out-of-bounds array access if bluetooth is
    disabled).
  * Fix memory leak.
  * Gtk3: Fix UI load.
  * Add user-share caja extension ini file.
  * Rename extension lib to libcaja-user-share.
  * Fix Glib >= 2.43 compatibility.
  * [obexftp] Fix spacing a bit.
  * Update translations.
- Spec cleanup.
* Sun Nov 23 2014 p.drouand@gmail.com
- Update to version 1.9.0 (unstable)
  + Add GTK3 support
- Bump version requirements
* Wed Mar  5 2014 p.drouand@gmail.com
- Update to version 1.8.0
  + no changes since version 1.7.90
* Thu Feb 20 2014 p.drouand@gmail.com
- Update to version 1.7.90 (unstable)
  + restore user-guide and port it to yelp.
  + disable bluetooth by default.
- Remove useless xz requirement
- Upstream use yelp-tools instead of mate-doc-utils; drop mate-doc-utils
  requirement and replace it with yelp-tools
- Add itstool and gnome-doc-utils require; new upstream dependency
* Wed Jan  1 2014 p.drouand@gmail.com
- Update to version 1.6.1
  + Fix data passed to disabled_timeout_callback
    In mate-user-share/src/user_share.c, the wrong variable is being
    passed as a gsettings pointer to the disabled_timeout_callback.
    https://bugs.launchpad.net/linuxmint/+bug/1005649/comments/36
  + Added manpage.
    Closes #10 (https://github.com/mate-desktop/mate-user-share/issues/10)
  + fix automake-1.13 deprecations
  + Add support for Apache HTTPD 2.4
  + Use mate-session to track the active session
  + Require dbus >= 1.1.1
  + Fix turning on sharing not starting mate-user-share
  + OpenBSD suffers from the same httpd race condition as the other BSDs
  + build: Add build options summary
  + make bluetooth really optional
  + add desktop files for autostart folder
  + Add support for Apache HTTPD 2.4
  + fix typo in share-extension.c
- Disable bluetooth support; mate-bluetooth has not been ported to bluez5
  yet
* Thu Sep 19 2013 johann.luce@wanadoo.fr
- Fix %%exclude problem for factory
  Add macro %%desktop_database_postun %%desktop_database_post
* Wed Apr  3 2013 p.drouand@gmail.com
- Update to version 1.6.0
  + no changes since 1.5.1
* Sat Mar 23 2013 p.drouand@gmail.com
- Update to version 1.5.1
  + fix GSettings path
  + use libnotify instead of libmatenotify
  + add mateconf-gsettings-data-convert file
- Replace libmatenotify BuildRequires with libnotify
- Do not include mateconf-gsettings-data-convert file in package
* Sun Dec  9 2012 nmo.marques@gmail.com
- Update to version 1.5.0
  + only add Bluetooth support to build if Bluetooth is available
  + migration to gsettings and fixes
  + lots of other fixes
* Tue Sep 11 2012 nmo.marques@gmail.com
- Initial package from version 1.4.1
